pub struct OPCCodec;Trait Implementations
Sourceimpl Decoder for OPCCodec
impl Decoder for OPCCodec
Sourcetype Item = OpcMessage
type Item = OpcMessage
The type of decoded frames.
Sourcefn decode(&mut self, buf: &mut BytesMut) -> Result<Option<OpcMessage>>
fn decode(&mut self, buf: &mut BytesMut) -> Result<Option<OpcMessage>>
Attempts to decode a frame from the provided buffer of bytes. Read more
Sourcefn decode_eof(&mut self, buf: &mut BytesMut) -> Result<Option<OpcMessage>>
fn decode_eof(&mut self, buf: &mut BytesMut) -> Result<Option<OpcMessage>>
A default method available to be called when there are no more bytes
available to be read from the underlying I/O. Read more